.equ    default_break_time = 88;
.equ    default_mab_time   = 8;

; A maximum of 256 output channels can be used (including start code).
; Caution: parts of the source code won't function well if the output_channels
; constant is set to a value less than 256!

.equ    output_channels = 256
.equ    output_min      = 96
.equ    output_max      = output_min + output_channels - 1

; A maximum of 246 input channels can be used (including start code),
; this leaves 10 bytes for the stack.

.equ    input_channels = 246
.equ    input_min      = output_max + 1
.equ    input_max      = input_min + input_channels - 1

.equ    table_min = output_min
.equ    table_max = input_max

; "flags" register bit definitions

.equ    force_mux_off                 = 6 ; force the multiplexer to be temporarily disabled?
.equ    merge_in_progress             = 5 ; was the output table limit passed, so that a merge from the DMX input table is in progress?
.equ    merge_status                  = 4 ; is the merge feature enabled?
.equ    mux_invert                    = 3 ; should multiplexer be inverted?
.equ    current_input_startcode_valid = 2 ; did current input startcode match mask?
.equ    input_wildcard                = 1 ; is input startcode wildcard enabled?
.equ    mux_status                    = 0 ; is multiplexer of the eight channels from the secondary parallel connector enabled?

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

.def    break_time              = R1  ; user configured break time (default 88)
.def    mab_time                = R2  ; user configured mark after break (MAB) time (default 8)
.def    mass_output_min_h       = R3
.def    mass_output_min_l       = R4
.def    mass_output_max_h       = R5
.def    mass_output_max_l       = R6
.def    output_max_h            = R7
.def    output_max_l            = R8
.def    flags                   = R9  ; register with bits for flags, see above for bit definitions
.def    mux_address             = R10 ; start address of the eight channels that can be multiplexed from the additional processor pins
.def    safekeeper              = R11 ; temporary buffer used by interrupts for safekeeping of values
.def    output_countdown        = R12 ; counter that keeps track of how many channels have been transmitted in a transmission cycle
.def    output_count            = R13 ; number of channels to output (possibly including start code)
.def    input_startcode         = R14 ; start code to listen for on input
.def    current_input_count     = R15 ; number of channels received on DMX input (excluding start code)
.def    rdata                   = R16 ; data received from the parallel port
.def    sdata                   = R17 ; data (only the 4 least significant bits matter) to be sent to the parallel port
.def    temp1                   = R18 ; temporary buffer 1 used outside of interrupt handlers
.def    temp2                   = R19 ; temporary buffer 2 used outside of interrupt handlers
.def    temp3                   = R20 ; temporary buffer used outside of interrupt handlers, meant for storing individual bits
.def    brk_temp                = R21 ; temporary buffer used exclusively by the break transmission routine
.def    tmr_temp                = R22 ; temporary buffer used exclusively by the timer interrupt handler
.def    rxd_temp                = R23 ; temporary buffer used exclusively by the irq_receive interrupt handler
.def    txd_temp                = R24 ; temporary buffer used exclusively by the irq_transmit interrupt handler
.def    dummy                   = R25 ; dummy register with a permanent value of 0 after initialization

; Use Y register as input pointer
.def    ptr_input_h = R29
.def    ptr_input_l = R28

; Use X register as output pointer
.def    ptr_output_h = R27
.def    ptr_output_l = R26

; Use Z register as temporary pointer
.def    ptr_temp_h = R31
.def    ptr_temp_l = R30
